WPStoreTokenResponse class

The WPStoreTokenResponse class is used to parse the response from the store token request.

Constructors

WPStoreTokenResponse({List? data, String? message, int? status})
WPStoreTokenResponse.fromJson(Map<String, dynamic> json)

Properties

data ↔ List?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited